==> cssj-pukiwiki-1_3_1.zip: cssj-pukiwiki/utf8/skin/cssj/pdfoptions.php <==
<?php
global $cssj_pdf_count;
if (isset($cssj_pdf_count)) {
	++$cssj_pdf_count;
}
else {
	$cssj_pdf_count = 0;
?>
<script tuype="text/javascript">
function cssj_pdf_show(id, href) {
	if (document.getElementById(id+'-pwck').checked) {
		href += '&output,pdf,encryption=v2';
		href += '&output,pdf,encryption,user-password='+document.getElementById(id+'-pw').value;
	}
	switch (document.getElementById(id+'-size').selectedIndex) {
	case 1:
		href += '&output,page-width=297mm';
		href += '&output,page-height=210mm';
		break;
	}
	if (document.getElementById(id+'-src').checked) {
		href += '&source=true';
	}
	window.open(href);
}
</script>
<?php
}
$id = "cssj_pdf$cssj_pdf_count";
?>
<img src="skin/cssj/print-skin/pdf_icon.gif" width="10" height="12"
     style="cursor: pointer;" class="cssj-pdflink"
     onClick="with(document.getElementById('<?php echo $id; ?>')){style.visibility='visible';};"/>
<span style="visibility: hidden; position: absolute; border: 1px solid Black; padding: 2pt; background-color: White; font-size: 9pt;"
      id="<?php echo $id; ?>">
<span style="display: block; text-align: right; font-size: 5pt; line-height: 7pt;">
<span style="cursor: pointer;" onClick="with(document.getElementById('<?php echo $id; ?>')){style.visibility='hidden';};">X</span>
</span>
<fieldset>
<legend>スタイル</legend>
<?php
foreach($styles as $name => $style) {
    $uri = "$href&amp;style=$style";
	echo "<a href=\"#\" onClick=\"javascript:cssj_pdf_show('$id', '$uri');\">$name</a><br />";
}
?>
</fieldset>
<fieldset>
<legend>オプション</legend>
<label><input id="<?php echo $id; ?>-src" type="checkbox" value="1" /> ブラウザで表示</label><br />
<label>サイズ<select id="<?php echo $id; ?>-size">
<option>A4タテ</option>
<option>A4ヨコ</option>
</select></label><br />
<label><input id="<?php echo $id; ?>-pwck" type="checkbox" value="1" onClick="xchecked=this.checked;with(document.getElementById('<?php echo $id; ?>-pw')){disabled=!xchecked;};" />パスワード</label><br />
<input id="<?php echo $id; ?>-pw" type="password" value="" disabled="disabled" />
</fieldset>
</span>

==> cssj-pukiwiki-1_3_2.zip: cssj-pukiwiki/utf8/skin/cssj/pdfoptions.php <==
<?php
global $cssj_pdf_count;
if (isset($cssj_pdf_count)) {
	++$cssj_pdf_count;
}
else {
	$cssj_pdf_count = 0;
?>
<script tuype="text/javascript">
function cssj_escape(str) {
	str = str.replace('%', '％');
	str = str.replace('&', '＆');
	return str;
}
function cssj_pdf_show(id, href) {
	if (document.getElementById(id+'-pwck').checked) {
		href += '&output,pdf,encryption=v2';
		href += '&output,pdf,encryption,user-password='+document.getElementById(id+'-pw').value;
	}
	switch (document.getElementById(id+'-size').selectedIndex) {
	case 1:
		href += '&output,page-width=297mm';
		href += '&output,page-height=210mm';
		break;
	}
	if (document.getElementById(id+'-src').checked) {
		href += '&source=true';
	}
	if (document.getElementById(id+'-author').value) {
		href += '&author='+cssj_escape(document.getElementById(id+'-author').value);
	}
	if (document.getElementById(id+'-title').value) {
		href += '&title='+cssj_escape(document.getElementById(id+'-title').value);
	}
	window.open(href);
}
</script>
<?php
}
$id = "cssj_pdf$cssj_pdf_count";
?>
<img src="skin/cssj/print-skin/pdf_icon.gif" width="10" height="12"
     alt="[PDF]" style="cursor: pointer;" class="cssj-pdflink"
     onClick="with(document.getElementById('<?php echo $id; ?>')){style.visibility='visible';};"/>
<span style="visibility: hidden; position: absolute; border: 1px solid Black; padding: 2pt; background-color: White; font: normal 9pt/1.2 monospace;"
      id="<?php echo $id; ?>">
<span style="display: block; text-align: right; font-size: 5pt; line-height: 7pt;">
<span style="cursor: pointer;" onClick="with(document.getElementById('<?php echo $id; ?>')){style.visibility='hidden';};">X</span>
</span>
<label>タイトル: <input type="text" id="<?php echo $id; ?>-title"></label><br/>
<label>作者:&nbsp;&nbsp;&nbsp;&nbsp; <input type="text" id="<?php echo $id; ?>-author"></label>
<fieldset>
<legend>スタイル</legend>
<?php
foreach($styles as $name => $style) {
    $uri = "$href&amp;style=$style";
	echo "<a href=\"#\" onClick=\"javascript:cssj_pdf_show('$id', '$uri');\">$name</a><br />";
}
?>
</fieldset>
<fieldset>
<legend>オプション</legend>
<label><input id="<?php echo $id; ?>-src" type="checkbox" value="1" /> ブラウザで表示</label><br />
<label>サイズ<select id="<?php echo $id; ?>-size">
<option>A4タテ</option>
<option>A4ヨコ</option>
</select></label><br />
<label><input id="<?php echo $id; ?>-pwck" type="checkbox" value="1" onClick="xchecked=this.checked;with(document.getElementById('<?php echo $id; ?>-pw')){disabled=!xchecked;};" />パスワード</label><br />
<input id="<?php echo $id; ?>-pw" type="password" value="" disabled="disabled" />
</fieldset>
</span>
